@@ -63,16 +63,32 @@ estg <- function(data_CO, COdate, data_SS, SSdate = NULL,
                  nsim = 1000, max_intervals = 8,
                  seed_SE = NULL, seed_CP = NULL, seed_g = NULL){
 
+# error-checking
+  if (is.null(unitCol))
+    unitCol <- defineUnitCol(data_CO = data_CO, data_SS = data_SS)
   SSdat <- prepSS(data_SS) # SSdat name distinguishes this as pre-formatted
+  if (any(! data_CO[, unitCol] %in% SSdat$unit))
+    stop("carcasses found (CO) at units not properly formatted (or missing) in SS")
   if (is.null(SSdate)) SSdate <- SSdat$SSdate
   SSdat$searches_unit[ , 1] <- 1 # set t0 as start of period of inference
   t0date <- SSdat$date0
-  dates_CO <- checkDate(data_CO[ , COdate])
-  if (is.null(dates_CO)) stop("dates_CO not properly formatted as dates")
-  if (t0date > min(dates_CO)) stop("first carcass discovered before first search date")
-  if (any(as.numeric(data_SS[cbind(
-      match(data_CO[, COdate], SSdat[[SSdate]]),
-      match(data_CO[, unitCol], names(data_SS)))]) == 0)){
+  dates_CO <- suppressWarnings(checkDate(data_CO[ , COdate]))
+  if (is.null(dates_CO))
+    stop("data_CO[ , COdate] values  not properly formatted as dates")
+  if (t0date > min(dates_CO))
+    stop("first carcass discovered before first search date")
+  rind <- match(dates_CO, SSdat[[SSdate]])
+  cind <- match(data_CO[, unitCol], names(data_SS))
+  if (anyNA(rind)){
+    stop("carcasses ", paste0(which(is.na(rind)), collapse = ', '),
+         " in CO found on dates not listed in SS")
+  }
+  if (anyNA(cind)){
+    stop("carcasses discovered at unit(s) ",
+      paste0(data_CO[rind, unitCol], collapse =", "),
+      "in CO...not represented in SS. Cannot estimate g or M.")
+  }
+  if (any(as.numeric(data_SS[cbind(rind, cind)]) == 0)){
     stop("some carcasses (CO) were found at turbines that were not searched (SS) ",
          "on the the date recorded for the carcass discovery")
   }
@@ -96,7 +112,7 @@ estg <- function(data_CO, COdate, data_SS, SSdate = NULL,
     }
   }
   sizeclass <- as.list(as.character(COdat[, sizeCol]))
-  sizeclasses <- unique(unlist(sizeclass))
+  sizeclasses <- sort(unique(unlist(sizeclass)))
   nsizeclass <- length(sizeclasses)
 # data pre-processing
 # create lists of arrays for SS (days) and cells (SE and CP)
@@ -111,6 +127,7 @@ estg <- function(data_CO, COdate, data_SS, SSdate = NULL,
       )
     }
   }
+
   preds_SE <- lapply(model_SE, function(x) x$predictors)
   preds_CP <- lapply(model_CP, function(x) x$predictors)
   preds <- mapply(function(x, y) unique(c(x, y)), preds_SE, preds_CP)
@@ -163,7 +180,9 @@ estg <- function(data_CO, COdate, data_SS, SSdate = NULL,
       }
       cells[[xi]]$CPrep <- length(days[[xi]]) - 1
     }
+
   } else {
+
     for (xi in 1:X){
       cells[[xi]] <- list()
       SEc <- SEr <- CPc <- CPr <- NULL
@@ -304,6 +323,7 @@ estg <- function(data_CO, COdate, data_SS, SSdate = NULL,
       }
     }
   }
+
   rownames(Aj) <- COdat[ , unitCol]
   out <- list("ghat" = ghat, "Aj" = Aj) # ordered by relevance to user
   return(out)
@@ -696,10 +716,10 @@ estgGenericSize <- function(days, modelSetSize_SE, modelSetSize_CP,
       !all(sizeclasses_CP %in% sizeclasses_SE)){
     stop("Size classes don't match between SE and CP model sets")
   }
-  sizeclasses <- unique(c(sizeclasses_SE, sizeclasses_CP))
+  sizeclasses <- sort(unique(c(sizeclasses_SE, sizeclasses_CP)))
   nsizeclass <- length(sizeclasses)
   # check whether k is included in every model. If not, error.
-  for (sci in 1:nsizeclass){
+  for (sci in sizeclasses){
     if (modelSetSize_SE[[sci]][[modelSizeSelections_SE[sci]]]$pOnly){
      stop("k required for SE model for size = ", sci)
     }
@@ -708,10 +728,8 @@ estgGenericSize <- function(days, modelSetSize_SE, modelSetSize_CP,
   for (sci in sizeclasses){
     if (any(unlist(lapply(modelSetSize_SE[[sci]], function(x) x$pOnly))))
       stop("No k included in SE model. Cannot estimate g")
-    model_SEsci <- modelSizeSelections_SE[[sci]]
-    model_SE <- modelSetSize_SE[[sci]][[model_SEsci]]
-    model_CPsci <- modelSizeSelections_CP[[sci]]
-    model_CP <- modelSetSize_CP[[sci]][[model_CPsci]]
+    model_SE <- modelSetSize_SE[[sci]][[modelSizeSelections_SE[[sci]]]]
+    model_CP <- modelSetSize_CP[[sci]][[modelSizeSelections_CP[[sci]]]]
     ghats[[sci]] <- estgGeneric(nsim = nsim, days = days,
       model_SE = model_SE, model_CP = model_CP,
       seed_SE = seed_SE, seed_CP = seed_CP)
@@ -864,10 +882,9 @@ summary.gGeneric <- function(object, ..., CL = 0.90){
 #'
 summary.gGenericSize <- function(object, ..., CL = 0.90){
 
-  nsizeclass <- length(object)
-  out <- vector("list", length = nsizeclass)
-  names(out) <- names(object)
-  for (sci in 1:nsizeclass){
+  sizeclasses <- names(object)
+  out <- list()
+  for (sci in sizeclasses){
     out[[sci]] <- summary(object[[sci]], ..., CL = CL)
   }
   return(out)
